/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
/// <reference types="node" />
import { EventEmitter } from "events";
import { IContext, IQueuedMessage, ILogger, IContextErrorData, IRoutingKey } from "@fluidframework/server-services-core";
export declare class DocumentContext extends EventEmitter implements IContext {
    private readonly routingKey;
    readonly log: ILogger | undefined;
    private readonly getLatestTail;
    private headInternal;
    private tailInternal;
    private closed;
    private contextError;
    constructor(routingKey: IRoutingKey, head: IQueuedMessage, log: ILogger | undefined, getLatestTail: () => IQueuedMessage);
    get head(): IQueuedMessage;
    get tail(): IQueuedMessage;
    /**
     * Returns whether or not there is pending work in flight - i.e. the head and tail are not equal
     */
    hasPendingWork(): boolean;
    /**
     * Updates the head offset for the context.
     */
    setHead(head: IQueuedMessage): void;
    checkpoint(message: IQueuedMessage): void;
    error(error: any, errorData: IContextErrorData): void;
    close(): void;
    getContextError(): undefined;
}
//# sourceMappingURL=documentContext.d.ts.map