/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
/// <reference types="node" />
import { EventEmitter } from "events";
import { IContext, IQueuedMessage, ILogger, IContextErrorData } from "@fluidframework/server-services-core";
import { CheckpointManager } from "./checkpointManager";
export declare class Context extends EventEmitter implements IContext {
    private readonly checkpointManager;
    readonly log: ILogger | undefined;
    private closed;
    constructor(checkpointManager: CheckpointManager, log: ILogger | undefined);
    /**
     * Updates the checkpoint for the partition
     */
    checkpoint(queuedMessage: IQueuedMessage): void;
    /**
     * Closes the context with an error.
     * @param error - The error object or string
     * @param errorData - Additional information about the error
     */
    error(error: any, errorData: IContextErrorData): void;
    /**
     * Closes the context
     */
    close(): void;
}
//# sourceMappingURL=context.d.ts.map