"use strict";
/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.Context = void 0;
const events_1 = require("events");
class Context extends events_1.EventEmitter {
    constructor(checkpointManager, log) {
        super();
        this.checkpointManager = checkpointManager;
        this.log = log;
        this.closed = false;
    }
    /**
     * Updates the checkpoint for the partition
     */
    checkpoint(queuedMessage) {
        if (this.closed) {
            return;
        }
        this.checkpointManager.checkpoint(queuedMessage).catch((error) => {
            if (this.closed) {
                // don't emit errors after closing
                return;
            }
            // Close context on error. Once the checkpointManager enters an error state it will stay there.
            // We will look to restart on checkpointing given it likely indicates a Kafka connection issue.
            this.error(error, { restart: true });
        });
    }
    /**
     * Closes the context with an error.
     * @param error - The error object or string
     * @param errorData - Additional information about the error
     */
    error(error, errorData) {
        this.emit("error", error, errorData);
    }
    /**
     * Closes the context
     */
    close() {
        this.closed = true;
        this.removeAllListeners();
    }
}
exports.Context = Context;
//# sourceMappingURL=context.js.map